==> write_composition-1.4.tar.gz: write_composition-1.4/README.md <==
# 废话生成器1.4

本项目是从原作者@lzyun的项目'bullshit'中衍生过来的，功能更加强大。

### 用途

非正式场合

### 实现原理

最终数据来源于 data.json 文件中的素材,里面的结构如下:

```json
{
 "title": "学生会退会",
 "famous": [
  "爱迪生a，天才是百分之一的勤奋加百分之九十九的汗水。b",
  "查尔斯·史a，一个人几乎可以在任何他怀有无限热忱的事情上成功。b",
  //....
  "卡耐基a, 我们若已接受最坏的，就再没有什么损失。b",
  "德国a, 只有在人群中间，才能认识自己。b",
  "史美尔斯a, 书籍把我们引入最美好的社会，使我们认识各个时代的伟大智者。b",
  "冯学峰a, 当一个人用工作去迎接光明，光明很快就会来照耀着他。b",
  "吉格·金克拉a, 如果你能做梦，你就能实现它。b"
 ],
 "bosh": [
  "现在, 解决x的问题, 是非常非常重要的. 所以, ",
  "我们不得不面对一个非常尴尬的事实, 那就是, ",
  "x的发生, 到底需要如何做到, 不x的发生, 又会如何产生. ",
  "而这些并不是完全重要, 更加重要的问题是, ",
  "x, 到底应该如何实现. ",
  //....
  "可是，即使是这样，x的出现仍然代表了一定的意义. ",
  "x似乎是一种巧合，但如果我们从一个更大的角度看待问题，这似乎是一种不可避免的事实. ",
  "在这种不可避免的冲突下，我们必须解决这个问题. ",
  "对我个人而言，x不仅仅是一个重大的事件，还可能会改变我的人生. "
 ],
 "after": [
  "这不禁令我深思. ",
  "带着这句话, 我们还要更加慎重的审视这个问题: ",
  "这启发了我. ",
  "我希望诸位也能好好地体会这句话. ",
  "这句话语虽然很短, 但令我浮想联翩. ",
  "这句话看似简单，但其中的阴郁不禁让人深思. ",
  "这句话把我们带到了一个新的维度去思考这个问题: ",
  "这似乎解答了我的疑惑. "
 ],
 "before": [
  "曾经说过",
  "在不经意间这样说过",
  "说过一句著名的话",
  "曾经提到过",
  "说过一句富有哲理的话"
 ],
 "web_sen": [
  "人格的完善是本，财富的确立是末。",
  "没有一种不通过蔑视忍受和奋斗就可以征服的命运。",
  "行动是治愈恐惧的良药，而犹豫、拖延将不断滋养恐惧。",
  //....
  "我不是骨头，不能让每条狗都追着跑。",
  "不能去骗别人，因为你能骗到的人，都是信任你的。",
  "不要给我压力，那将是我成为你上司的动力。"
 ],
 "lz_sen": [
  "有挫败才有成长。",
  "能坚持别人不能坚持的，才能拥有别人不能拥有的。",
  //....
  "时光匆匆流逝过，平平淡淡才是真。忍耐任由风雨过，守得云开见月明。",
  "明天是世上增值最快的一块土地，因它充满了希望。",
  "要相信自己的眼睛，不要相信别人的嘴。"
 ]
}
```

`famous` 是名人语录, 里面的关键字"a"和"b" 将分别被 `before` 和 `after` 中的内容替换,这样是的句子前后显得具有逻辑性.`bosh` 是一句废话, 里面的关键字"x"将被标题替换.
`web_sen` 是网络流行语， `lz_sen` 是励志名言.

一篇文章的构成就是不断随机获取famous和bosh列表的元素,并适当添加web_sen&lz_sen,最后拼凑成一篇文章.

### 如何使用

```python
from write_composition import generator
content = generator("刷题无用")
print(content)
```
输出

```
人活着要呼吸。呼者，出一口气；吸者，争一口气。生活中, 若刷题无用出现了, 我们就不得不考虑它出现了的事实. 可是，即使是这样，刷题无用的出现仍然代表了一定的意义. 塞内加在不经意间这样说过, 勇气通往天堂，怯懦通往地狱。这不禁令我深思. 青春就是疯狂的奔跑，然后华丽的跌倒。唾沫是用来数钞票的，而不是用来讲道理的。

前方无绝路，希望在转角。伟人之所以伟大，是因为他与别人共处逆境时，别人失去了信心，他却下决心实现自己的目标。自己打败自己是最可悲的失败，自己战胜自己是最可贵的胜利。我们都知道, 只要有意义, 那么就必须慎重考虑.既然如此, 斯宾诺莎曾经说过, 最大的骄傲于最大的自卑都表示心灵的最软弱无力。这句话语虽然很短, 但令我浮想联翩. 唯有行动才能改造命运如果考试用QB做奖励，那么国家马上就会富强的。别小看任何人，越不起眼的人，往往会做些让人想不到的事。韩非说过一句富有哲理的话, 内外相应，言行相称。这句话语虽然很短, 但令我浮想联翩. 如果说剪掉头发就是剪掉回忆，那我剪成光头是不是可以失忆。没有一种不通过蔑视忍受和奋斗就可以征服的命运。非洲说过一句著名的话, 最灵繁的人也看不见自己的背脊。这句话看似简单，但其中的阴郁不禁让人深思. 人生至善，就是对生活乐观，对工作愉快，对事业兴奋。自己打败自己是最可悲的失败，自己战胜自己是最可贵的胜利感谢黑夜的来临，我知道今日无论有多失败，全新的明天仍然等待着我去证明自己。刷题无用因何而发生?每一天开心笑，累了就睡觉，醒了就微笑。生活，没什么大不了！刷题无用因何而发生?既然如此, 而这些并不是完全重要, 更加重要的问题是, 爱迪生曾经提到过，天才是百分之一的勤奋加百分之九十九的汗水。带着这句话, 我们还要更加慎重的审视这个问题: 昨晚多几分钟的准备，今天少几小时的麻烦。祸福无门，唯人自召。这种事实对本人来说意义重大, 相信对这个世界也是有一定意义的.
```

指定内容长度

```python
content = generator("刷题无用", lenth=1000)
print(content)
```

输出
```
人生的好处不在于拿一手好牌，而在于打好一手坏牌。不要等待好事降临，你要向幸福进发。刷题无用因何而发生?眼睛的鲜活便滋润了奋斗的鲜活，拼搏的鲜活，智慧的鲜活，成功的鲜活。贝多芬曾经说过, 卓越的人一大优点是：在不利与艰难的遭遇里百折不饶。这句话语虽然很短, 但令我浮想联翩. 祸福无门，唯人自召。人要脸树要皮，电线杆子要水泥。生活中, 若刷题无用出现了, 我们就不得不考虑它出现了的事实. 如果做某一件事能给我带来好情绪，那么无论遇到什么样的挫折，我都会竭力去做。天塌下来，有个高的人帮你扛着，但是你能保证，天塌下来的时候，个儿高的人没在弯腰吗？之后，还不是得靠自己！愚痴的人，一向想要别人了解他。有智慧的人，却努力的了解自己。培根说过一句富有哲理的话, 深窥自己的心，而后发觉一切的奇迹在你自己。这启发了我. 命运总是光临在那些有准备的人身上行动是治愈恐惧的良药，而犹豫、拖延将不断滋养恐惧。罗曼·罗兰说过一句富有哲理的话, 只有把抱怨环境的心情，化为上进的力量，才是成功的保证。这启发了我. 每个人生下来都要从事某项事业，每一个活在地还应上的人都有自己生活中的义务。没有变化的生活，就像织布机上的经纬，一匹一匹的岁月都织出来了，而花色却是一个样子的单调。我们终其一生，就是要摆脱别人的期待，找到真正的自己。我们一般认为, 抓住了问题的关键, 其他一切则会迎刃而解.

敢于尝试，就等于你已经向成功迈出了第一步。我们不得不面对一个非常尴尬的事实, 那就是, 在这种不可避免的冲突下，我们必须解决这个问题. 白哲特曾经提到过，坚强的信念能赢得强者的心，并使他们变得更坚强。这似乎解答了我的疑惑. 可以解决的事情不用担心；不能解决的事情担心也没用。没有一种不通过蔑视忍受和奋斗就可以征服的命运。人活着要呼吸。呼者，出一口气；吸者，争一口气。所谓刷题无用, 关键是刷题无用需要如何写. 池田大作曾经提到过, 不要回避苦恼和困难，挺起身来向它挑战，进而克服它。这句话把我们带到了一个新的维度去思考这个问题: 不能去骗别人，因为你能骗到的人，都是信任你的。如果考试用QB做奖励，那么国家马上就会富强的。

这样看来, 

我们不妨可以这样来想: 海贝尔曾经说过, 人生就是学校。在那里，与其说好的教师是幸福，不如说好的教师是不幸。我希望诸位也能好好地体会这句话. 灰色的理论到处都有,我的朋友,只有生活之树四季常青,郁郁葱葱我不是骨头，不能让每条狗都追着跑。
```

生成并写入文件

```python
from write_composition import make_and_write

make_and_write(title = '我爱Python', lenth = 900)
```

会在脚本当前目录下生成txt文件，名称为输入的title

==> write_composition-1.6.tar.gz: write_composition-1.6/README.md <==
# 废话生成器1.6

本项目是从原作者@lzyun的项目'bullshit'中衍生过来的，功能更加强大。

### 用途

非正式场合

### 实现原理

最终数据来源于 data.json 文件中的素材,里面的结构如下:

```json
{
 "title": "学生会退会",
 "famous": [
  "爱迪生a，天才是百分之一的勤奋加百分之九十九的汗水。b",
  "查尔斯·史a，一个人几乎可以在任何他怀有无限热忱的事情上成功。b",
  //....
  "卡耐基a, 我们若已接受最坏的，就再没有什么损失。b",
  "吉格·金克拉a, 如果你能做梦，你就能实现它。b"
 ],
 "bosh": [
  "现在, 解决x的问题, 是非常非常重要的. 所以, ",
  "我们不得不面对一个非常尴尬的事实, 那就是, ",
  "x, 到底应该如何实现. ",
  //....
  "对我个人而言，x不仅仅是一个重大的事件，还可能会改变我的人生. "
 ],
 "after": [
  "这不禁令我深思. ",
  //...
  "这句话把我们带到了一个新的维度去思考这个问题: ",
  "这似乎解答了我的疑惑. "
 ],
 "before": [
  "曾经说过",
  "在不经意间这样说过",
  "说过一句著名的话",
  "曾经提到过",
  "说过一句富有哲理的话"
 ],
 "web_sen": [
  "人格的完善是本，财富的确立是末。",
  "没有一种不通过蔑视忍受和奋斗就可以征服的命运。",
  "行动是治愈恐惧的良药，而犹豫、拖延将不断滋养恐惧。",
  //....
  "我不是骨头，不能让每条狗都追着跑。",
  "不能去骗别人，因为你能骗到的人，都是信任你的。",
  "不要给我压力，那将是我成为你上司的动力。"
 ],
 "lz_sen": [
  "有挫败才有成长。",
  "能坚持别人不能坚持的，才能拥有别人不能拥有的。",
  //....
  "明天是世上增值最快的一块土地，因它充满了希望。",
  "要相信自己的眼睛，不要相信别人的嘴。"
 ]
}
```

`famous` 是名人语录, 里面的关键字"a"和"b" 将分别被 `before` 和 `after` 中的内容替换,这样是的句子前后显得具有逻辑性.`bosh` 是一句废话, 里面的关键字"x"将被标题替换.
`web_sen` 是网络流行语， `lz_sen` 是励志名言.

一篇文章的构成就是不断随机获取famous和bosh列表的元素,并适当添加web_sen&lz_sen,最后拼凑成一篇文章.

### 如何使用

```python
from write_composition import generator
content = generator("刷题无用")
print(content)
```
输出

```
人活着要呼吸。呼者，出一口气；吸者，争一口气。生活中, 若刷题无用出现了, 我们就不得不考虑它出现了的事实. 可是，即使是这样，刷题无用的出现仍然代表了一定的意义. 塞内加在不经意间这样说过, 勇气通往天堂，怯懦通往地狱。这不禁令我深思. 青春就是疯狂的奔跑，然后华丽的跌倒。唾沫是用来数钞票的，而不是用来讲道理的。
#...
前方无绝路，希望在转角。伟人之所以伟大，是因为他与别人共处逆境时，别人失去了信心，他却下决心实现自己的目标。带着这句话, 我们还要更加慎重的审视这个问题: 昨晚多几分钟的准备，今天少几小时的麻烦。祸福无门，唯人自召。这种事实对本人来说意义重大, 相信对这个世界也是有一定意义的.
```

指定内容长度

```python
content = generator("刷题无用", lenth=1000)
print(content)
```

输出
```
人生的好处不在于拿一手好牌，而在于打好一手坏牌。不要等待好事降临，你要向幸福进发。刷题无用因何而发生?眼睛的鲜活便滋润了奋斗的鲜活，拼搏的鲜活，智慧的鲜活，成功的鲜活。祸福无门，唯人自召。人要脸树要皮，电线杆子要水泥。生活中, 若刷题无用出现了, 我们就不得不考虑它出现了的事实. 如果做某一件
这样看来, 
#...
我们不妨可以这样来想: 海贝尔曾经说过, 人生就是学校。在那里，与其说好的教师是幸福，不如说好的教师是不幸。我希望诸位也能好好地体会这句话. 灰色的理论到处都有,我的朋友,只有生活之树四季常青,郁郁葱葱我不是骨头，不能让每条狗都追着跑。
```

生成并写入文件

```python
from write_composition import make_and_write

make_and_write(title = '我爱Python', lenth = 900)
```

会在脚本当前目录下生成txt文件，名称为输入的title

### 新增功能

相较于write_composition1.4，1.5版本新增'only'功能

### 数据结构

```json
[
 "最灵繁的人也看不见自己的背脊。",
 //...
 "不要回避苦恼和困难，挺起身来向它挑战，进而克服它。"
]
```

### 如何使用

```python
from write_composition import only
print(only(type_ = 'famous_quotes'))
```
输出
```
学到很多东西的诀窍，就是一下子不要学很多。熟读唐诗三百首，不会作诗也会吟。我的努力求学没有得到别的好处，只不过是愈来愈发觉自己的无知。三军可夺帅也，匹夫不可夺志也。意志是一个强壮的盲人，倚靠在明眼的跛子肩上。读书忌死读，死读钻牛角。最大的挑战和突破在于用人，而用人最大的突破在于信任人。有时候读书是一种巧妙地避开思考的方法。有勇气承担命运这才是英雄好汉。
#...
最灵繁的人也看不见自己的背脊。重复别人所说的话，只需要教育；而要挑战别人所说的话，则需要头脑。最大的挑战和突破在于用人，而用人最大的突破在于信任人。好的书籍是最贵重的珍宝。业余生活要有意义，不要越轨。
```
指定长度
```python
from write_composition import only
print(only(type_ = 'famous_quotes', lenth = 1000))
```
输出
```
阅读使人充实，会谈使人敏捷，写作使人精确。勇猛大胆和坚定的决心能够抵得上武器的精良。阅读一切好书如同和过去最杰出的人谈话。只有把抱怨环境的心情，化为上进的力量，才是成功的保证。问渠哪得清如许，为有源头活水来。读书是在别人思想的帮助下，建立起自己的思想。
#...
读书是在别人思想的帮助下，建立起自己的思想。最大的挑战和突破在于用人，而用人最大的突破在于信任人。
```

### 更新说明

名言库扩充

### 注意

`olny`功能目前仅支持`'famous_quotes'`(名言)
